@@ -4,6 +4,7 @@ import Data.GI.CodeGen.CabalHooks (setupBinding, TaggedOverride(..))
 
 import qualified GI.GLib.Config as GLib
 import qualified GI.GObject.Config as GObject
+import qualified GI.Gio.Config as Gio
 import qualified GI.HarfBuzz.Config as HarfBuzz
 
 
@@ -12,8 +13,8 @@ main = setupBinding name version pkgName pkgVersion verbose overridesFile inheri
   where name = "Pango"
         version = "1.0"
         pkgName = "gi-pango"
-        pkgVersion = "1.0.27"
+        pkgVersion = "1.0.29"
         overridesFile = Just "Pango.overrides"
         verbose = False
         outputDir = Nothing
-        inheritedOverrides = [TaggedOverride "inherited:GLib" GLib.overrides, TaggedOverride "inherited:GObject" GObject.overrides, TaggedOverride "inherited:HarfBuzz" HarfBuzz.overrides]
+        inheritedOverrides = [TaggedOverride "inherited:GLib" GLib.overrides, TaggedOverride "inherited:GObject" GObject.overrides, TaggedOverride "inherited:Gio" Gio.overrides, TaggedOverride "inherited:HarfBuzz" HarfBuzz.overrides]
